pub enum TensorOpsError {
DimOutOfBounds(usize, usize),
LengthMismatch(usize, usize),
ShapeMismatch(Vec<usize>, Vec<usize>),
TensorError(TensorError),
}Expand description
An error type for tensor operations.
Variants
DimOutOfBounds(usize, usize)
The dimension to perform the operation over is greater than the number of dimsions of the tensor.
LengthMismatch(usize, usize)
Length mismatch for vector operations
ShapeMismatch(Vec<usize>, Vec<usize>)
Shape mismatch
TensorError(TensorError)
Tensor error